Example: Global Likelihood fitting
==================================

In this example, we shall perform likelihood fitting to two data sets at the
same time to show how likelihood fitting can be used to fit multiple data sets
at the same time.

First we will fit using a different parameter for each data set, and then with
the same for both data sets. This shows the ease with which we can experiment
with different models.

.. literalinclude:: ../../examples/multidataset_likelihood.py
    :language: python
